@@ -8,7 +8,8 @@ from ..utils.file import get_code_from_markdown, write_file
 def create_typescript_environment(directory_path: Optional[str] = None) -> str:
     if directory_path == None:
         directory_path = './docrunner-build-ts'
-        os.mkdir(directory_path)
+        if not os.path.exists(directory_path):
+            os.mkdir(directory_path)
 
     return directory_path
 
@@ -16,13 +17,16 @@ def create_typescript_environment(directory_path: Optional[str] = None) -> str:
 def compile_typescript(filepath: str) -> int:
     directory_path = str(Path(filepath).parent)
     compile_command = f'tsc {filepath}'
+    compile_exit_code = 0
+
     if os.path.exists(f'{directory_path}/tsconfig.json'):
         compile_command = f'tsc -p .'
-
-    base = os.getcwd()
-    os.chdir(os.path.join(base, directory_path))
-    compile_exit_code = os.system(compile_command)
-    os.chdir(base)
+        base = os.getcwd()
+        os.chdir(os.path.join(base, directory_path))
+        compile_exit_code = os.system(compile_command)
+        os.chdir(base)
+    else:
+        compile_exit_code = os.system(compile_command)
 
     return compile_exit_code
 
